# Reference Manual

This reference shows you how to use DynaCLI with most of its features, step by step.

Each section gradually builds on the previous ones, but it's structured to separate topics,
so that you can go directly to any specific one to solve your specific needs.

It is also built to work as a future reference.

So you can come back and see exactly what you need.

---

## Install DynaCLI

```bash
$ pip3 install dynacli
```

As we have zero 3rd party dependencies, DynaCLI will just install single module and that's it.
